//
//  MyDocument.h
//  JavaScriptEditor
//
//  Created by Raphael on Sun Aug 08 2004.
//


#import <Cocoa/Cocoa.h>

#import "BrowserController.h"
//#import "FindTableViewDataSource.h"

extern NSString *SplitPositionKey;

#define Forward YES
#define Backward NO

@class BrowserController;

@interface MyDocument : NSDocument
{
    IBOutlet id firstResponder;
    
    NSString *string;    
	
	IBOutlet NSTextView		*textView;
    IBOutlet NSTextView		*splitTextView;
    IBOutlet NSTextField	*documentTypeDisplay;
    IBOutlet NSWindow		*docWindow;
    IBOutlet NSSplitView	*splitView;
	IBOutlet NSTableView	*tableView;
    
    NSString				*documentType;
    BOOL					isEmptyDocument;
    BOOL					docTypeHasBeenDisplayed;
    
	IBOutlet NSSearchField	*searchFieldOutlet;
    
    IBOutlet NSToolbarItem	*activeSearchItem;
	IBOutlet NSMatrix		*searchToolbarButtons;
    
    IBOutlet NSPanel		*linePanel;
    IBOutlet NSTextField	*lineBox;
	
	IBOutlet NSPanel		*insertTextPanel;
	IBOutlet NSTextView		*insertTextTextView;
	
	IBOutlet NSWindow		*findWindow;
	
	NSString				*findString;
    IBOutlet NSTextField	*findTextField;
	IBOutlet NSTextField	*statusField;
	BOOL					findStringChangedSinceLastPasteboardUpdate;
    BOOL					lastFindWasSuccessful;
	IBOutlet NSTableView	*findTableView;
	NSMutableArray			*findResultArray;
	
	IBOutlet NSPanel		*correctionPanel;
	IBOutlet NSTextView		*correctionTextView;
	IBOutlet NSTextView		*errorsTextView;
	
	IBOutlet BrowserController *browserController;
	
	IBOutlet NSDrawer		*searchDrawer;
	NSMutableDictionary		*searchResult;
}
+ (void)initialize;
- (void)awakeFromNib;

- (void) setString:(NSString *)value;
- (void) updateView;
- (void) documentContentChanged;
- (void) setupToolbar;
- (IBAction) showLinePanel:(id)sender;
- (IBAction) sendGoToLine:(id)sender;
- (IBAction) cancelLinePanel:(id)sender;

- (IBAction) insertHeader:(id)sender;

- (IBAction) includeFile:(id)sender;

- (IBAction) importTextFromFile:(id)sender;

- (IBAction)closeInsertTextPanel:(id)sender;
- (IBAction) chooseInsertTextFile:(id)sender;
- (IBAction) insertText:(id) sender;

/* Common way to get a text finder. One instance of TextFinder per app is good enough. */
+ (id)sharedInstance;

/* Main method for external users; does a find in the first responder. Selects found range or beeps. */
- (BOOL)find:(BOOL)direction;

/* Gets the first responder and returns it if it's an NSTextView */
- (NSTextView *)textObjectToSearchIn;

/* Get/set the current find string. Will update UI if UI is loaded */
- (NSString *)findString;
- (void)setFindString:(NSString *)string;

/* Misc internal methods */
- (void)appDidActivate:(NSNotification *)notification;
- (void)appWillDeactivate:(NSNotification *)notification;
- (void)loadFindStringFromPasteboard;
- (void)loadFindStringToPasteboard;

- (void)findNext:(id)sender;
- (void)findPrevious:(id)sender;

/* Methods of the find table view */
- (NSArray *)findResultArray;

- (void) searchUsingSearchPanel:(id) sender;
- (void) searchUsingToolbarTextField:(id) sender;

- (void) fontChangedToFont:(NSFont *)font fromView:(NSTextView *)theView;
- (void) colorChangedToColor:(NSColor *)color fromView:(NSTextView *)theView;

- (IBAction) verifyHTML:(id)sender;
- (void)analysorDidFinish:(NSNotification *)note;
- (IBAction)correct:(id)sender;
- (IBAction)cancelCorrect:(id)sender;

- (IBAction)previewHTML:(id)sender;
- (IBAction)preview:(id)sender;
- (void)openDocumentInBrowser:(id)sender;

- (int)numberOfRowsInTableView:(NSTableView *)aTableView;
- (id)tableView:(NSTableView *)aTableView objectValueForTableColumn:(NSTableColumn *)aTableColumn row:(int)rowIndex;
@end

extern NSString *FindStringChangedNotification;

